@@ -3,12 +3,16 @@
 import operator
 import itertools
 import datetime
+from sql import Table
+from sql.functions import Overlay, Position
+from sql.aggregate import Max
+from sql.operators import Concat
 
 from trytond.model import Workflow, ModelView, ModelSQL, fields
 from trytond.modules.company import CompanyReport
 from trytond.wizard import Wizard, StateTransition, StateView, StateAction, \
     Button
-from trytond.backend import TableHandler
+from trytond import backend
 from trytond.pyson import Eval, Not, Equal, If, Or, And, Bool, In, Get, Id
 from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
@@ -46,7 +50,7 @@ class ShipmentIn(Workflow, ModelSQL, ModelView):
             },
         domain=[
             ('id', If(In('company', Eval('context', {})), '=', '!='),
-                Get(Eval('context', {}), 'company', 0)),
+                Eval('context', {}).get('company', -1)),
             ],
         depends=['state'])
     reference = fields.Char("Reference", size=None, select=True,
@@ -79,7 +83,7 @@ class ShipmentIn(Workflow, ModelSQL, ModelView):
     warehouse_storage = fields.Function(fields.Many2One('stock.location',
             'Warehouse Storage', on_change_with=['warehouse']),
         'on_change_with_warehouse_storage')
-    incoming_moves = fields.Function(fields.One2Many('stock.move', None,
+    incoming_moves = fields.Function(fields.One2Many('stock.move', 'shipment',
             'Incoming Moves',
             add_remove=[
                 ('shipment', '=', None),
@@ -99,7 +103,7 @@ class ShipmentIn(Workflow, ModelSQL, ModelView):
             depends=['state', 'warehouse', 'supplier_location',
                 'warehouse_input', 'company']),
         'get_incoming_moves', setter='set_incoming_moves')
-    inventory_moves = fields.Function(fields.One2Many('stock.move', None,
+    inventory_moves = fields.Function(fields.One2Many('stock.move', 'shipment',
             'Inventory Moves',
             domain=[
                 ('from_location', '=', Eval('warehouse_input')),
@@ -116,6 +120,7 @@ class ShipmentIn(Workflow, ModelSQL, ModelView):
     moves = fields.One2Many('stock.move', 'shipment', 'Moves',
         domain=[('company', '=', Eval('company'))], readonly=True,
         depends=['company'])
+    origins = fields.Function(fields.Char('Origins'), 'get_origins')
     code = fields.Char("Code", size=None, select=True, readonly=True)
     state = fields.Selection([
         ('draft', 'Draft'),
@@ -160,22 +165,42 @@ class ShipmentIn(Workflow, ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
         cursor = Transaction().cursor
+        model_data = Table('ir_model_data')
+        model = Table('ir_model')
+        model_field = Table('ir_model_field')
+        sql_table = cls.__table__()
+
         # Migration from 1.2: packing renamed into shipment
-        cursor.execute("UPDATE ir_model_data "
-            "SET fs_id = REPLACE(fs_id, 'packing', 'shipment') "
-            "WHERE fs_id like '%%packing%%' AND module = %s",
-            (module_name,))
-        cursor.execute("UPDATE ir_model "
-            "SET model = REPLACE(model, 'packing', 'shipment') "
-            "WHERE model like '%%packing%%' AND module = %s",
-            (module_name,))
-        cursor.execute("UPDATE ir_model_field "
-            "SET relation = REPLACE(relation, 'packing', 'shipment'), "
-                "name = REPLACE(name, 'packing', 'shipment') "
-            "WHERE (relation like '%%packing%%' "
-                "OR name like '%%packing%%') AND module = %s",
-            (module_name,))
+        cursor.execute(*model_data.update(
+                columns=[model_data.fs_id],
+                values=[Overlay(model_data.fs_id, 'shipment',
+                        Position('packing', model_data.fs_id),
+                        len('packing'))],
+                where=model_data.fs_id.like('%packing%')
+                & (model_data.module == module_name)))
+        cursor.execute(*model.update(
+                columns=[model.model],
+                values=[Overlay(model.model, 'shipment',
+                        Position('packing', model.model),
+                        len('packing'))],
+                where=model.model.like('%packing%')
+                & (model.module == module_name)))
+        cursor.execute(*model_field.update(
+                columns=[model_field.relation],
+                values=[Overlay(model_field.relation, 'shipment',
+                        Position('packing', model_field.relation),
+                        len('packing'))],
+                where=model_field.relation.like('%packing%')
+                & (model_field.module == module_name)))
+        cursor.execute(*model_field.update(
+                columns=[model_field.name],
+                values=[Overlay(model_field.name, 'shipment',
+                        Position('packing', model_field.name),
+                        len('packing'))],
+                where=model_field.name.like('%packing%')
+                & (model_field.module == module_name)))
 
         old_table = 'stock_packing_in'
         if TableHandler.table_exist(cursor, old_table):
@@ -196,22 +221,23 @@ class ShipmentIn(Workflow, ModelSQL, ModelView):
         Move = Pool().get('stock.move')
         if (not created_company
                 and TableHandler.table_exist(cursor, Move._table)):
-            cursor.execute('SELECT shipment.id, MAX(move.company) '
-                'FROM "%s" AS shipment '
-                'INNER JOIN "%s" AS move '
-                'ON \'%s,\' || shipment.id = move.shipment '
-                'GROUP BY shipment.id '
-                'ORDER BY MAX(move.company)'
-                % (cls._table, Move._table, cls.__name__))
+            move = Move.__table__()
+            cursor.execute(*sql_table.join(move,
+                    condition=(Concat(cls.__name__ + ',', sql_table.id)
+                        == move.shipment)
+                    ).select(sql_table.id, Max(move.company),
+                    group_by=sql_table.id,
+                    order_by=Max(move.company)))
             for company_id, values in itertools.groupby(cursor.fetchall(),
                     operator.itemgetter(1)):
                 shipment_ids = [x[0] for x in values]
                 for i in range(0, len(shipment_ids), cursor.IN_MAX):
                     sub_ids = shipment_ids[i:i + cursor.IN_MAX]
-                    red_sql, red_ids = reduce_ids('id', sub_ids)
-                    cursor.execute('UPDATE "' + cls._table + '" '
-                        'SET company = %s WHERE ' + red_sql,
-                        [company_id] + red_ids)
+                    red_sql = reduce_ids(sql_table.id, sub_ids)
+                    cursor.execute(*sql_table.update(
+                            columns=[sql_table.company],
+                            values=[company_id],
+                            where=red_sql))
             table.not_null_action('company', action='add')
 
         # Add index on create_date
@@ -234,10 +260,10 @@ class ShipmentIn(Workflow, ModelSQL, ModelView):
         return Transaction().context.get('company')
 
     def on_change_supplier(self):
-        if not self.supplier:
-            return {'contact_address': None}
-        address = self.supplier.address_get()
-        return {'contact_address': address.id}
+        address = None
+        if self.supplier:
+            address = self.supplier.address_get()
+        return {'contact_address': address.id if address else None}
 
     def on_change_with_supplier_location(self, name=None):
         if self.supplier:
@@ -325,6 +351,15 @@ class ShipmentIn(Workflow, ModelSQL, ModelView):
                     'planned_date': inventory_date,
                     })
 
+    @classmethod
+    def get_origins(cls, shipments, name):
+        origins = {}
+        with Transaction().set_user(0, set_context=True):
+            for shipment in cls.browse(shipments):
+                origins[shipment.id] = ', '.join(set(itertools.ifilter(None,
+                            (m.origin_name for m in shipment.moves))))
+        return origins
+
     @classmethod
     def create(cls, vlist):
         pool = Pool()
@@ -450,7 +485,7 @@ class ShipmentInReturn(Workflow, ModelSQL, ModelView):
             },
         domain=[
             ('id', If(In('company', Eval('context', {})), '=', '!='),
-                Get(Eval('context', {}), 'company', 0)),
+                Eval('context', {}).get('company', -1)),
             ],
         depends=['state'])
     code = fields.Char("Code", size=None, select=True, readonly=True)
@@ -482,6 +517,7 @@ class ShipmentInReturn(Workflow, ModelSQL, ModelView):
             ('company', '=', Eval('company')),
             ],
         depends=['state', 'from_location', 'to_location', 'company'])
+    origins = fields.Function(fields.Char('Origins'), 'get_origins')
     state = fields.Selection([
         ('draft', 'Draft'),
         ('cancel', 'Canceled'),
@@ -537,7 +573,9 @@ class ShipmentInReturn(Workflow, ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
         cursor = Transaction().cursor
+        sql_table = cls.__table__()
         # Migration from 1.2: packing renamed into shipment
         old_table = 'stock_packing_in_return'
         if TableHandler.table_exist(cursor, old_table):
@@ -558,22 +596,23 @@ class ShipmentInReturn(Workflow, ModelSQL, ModelView):
         Move = Pool().get('stock.move')
         if (not created_company
                 and TableHandler.table_exist(cursor, Move._table)):
-            cursor.execute('SELECT shipment.id, MAX(move.company) '
-                'FROM "%s" AS shipment '
-                'INNER JOIN "%s" AS move '
-                'ON \'%s,\' || shipment.id = move.shipment '
-                'GROUP BY shipment.id '
-                'ORDER BY MAX(move.company)'
-                % (cls._table, Move._table, cls.__name__))
+            move = Move.__table__()
+            cursor.execute(*sql_table.join(move,
+                    condition=(Concat(cls.__name__ + ',', sql_table.id)
+                        == move.shipment)
+                    ).select(sql_table.id, Max(move.company),
+                    group_by=sql_table.id,
+                    order_by=Max(move.company)))
             for company_id, values in itertools.groupby(cursor.fetchall(),
                     operator.itemgetter(1)):
                 shipment_ids = [x[0] for x in values]
                 for i in range(0, len(shipment_ids), cursor.IN_MAX):
                     sub_ids = shipment_ids[i:i + cursor.IN_MAX]
-                    red_sql, red_ids = reduce_ids('id', sub_ids)
-                    cursor.execute('UPDATE "' + cls._table + '" '
-                        'SET company = %s WHERE ' + red_sql,
-                        [company_id] + red_ids)
+                    red_sql = reduce_ids(sql_table.id, sub_ids)
+                    cursor.execute(*sql_table.update(
+                            columns=[sql_table.company],
+                            values=[company_id],
+                            where=red_sql))
             table.not_null_action('company', action='add')
 
         # Add index on create_date
@@ -608,6 +647,15 @@ class ShipmentInReturn(Workflow, ModelSQL, ModelView):
                     'planned_date': shipment._move_planned_date,
                     })
 
+    @classmethod
+    def get_origins(cls, shipments, name):
+        origins = {}
+        with Transaction().set_user(0, set_context=True):
+            for shipment in cls.browse(shipments):
+                origins[shipment.id] = ', '.join(set(itertools.ifilter(None,
+                            (m.origin_name for m in shipment.moves))))
+        return origins
+
     @classmethod
     def create(cls, vlist):
         pool = Pool()
@@ -743,7 +791,7 @@ class ShipmentOut(Workflow, ModelSQL, ModelView):
             },
         domain=[
             ('id', If(In('company', Eval('context', {})), '=', '!='),
-                Get(Eval('context', {}), 'company', 0)),
+                Eval('context', {}).get('company', -1)),
             ],
         depends=['state'])
     customer = fields.Many2One('party.party', 'Customer', required=True,
@@ -777,7 +825,7 @@ class ShipmentOut(Workflow, ModelSQL, ModelView):
     warehouse_output = fields.Function(fields.Many2One('stock.location',
             'Warehouse Output', on_change_with=['warehouse']),
         'on_change_with_warehouse_output')
-    outgoing_moves = fields.Function(fields.One2Many('stock.move', None,
+    outgoing_moves = fields.Function(fields.One2Many('stock.move', 'shipment',
             'Outgoing Moves',
             domain=[
                 ('from_location', '=', Eval('warehouse_output')),
@@ -791,7 +839,7 @@ class ShipmentOut(Workflow, ModelSQL, ModelView):
             depends=['state', 'warehouse', 'customer', 'warehouse_output',
                 'customer_location', 'company']),
         'get_outgoing_moves', setter='set_outgoing_moves')
-    inventory_moves = fields.Function(fields.One2Many('stock.move', None,
+    inventory_moves = fields.Function(fields.One2Many('stock.move', 'shipment',
             'Inventory Moves',
             domain=[
                 ('from_location', 'child_of', [Eval('warehouse_storage', -1)],
@@ -809,6 +857,7 @@ class ShipmentOut(Workflow, ModelSQL, ModelView):
     moves = fields.One2Many('stock.move', 'shipment', 'Moves',
         domain=[('company', '=', Eval('company'))], depends=['company'],
         readonly=True)
+    origins = fields.Function(fields.Char('Origins'), 'get_origins')
     code = fields.Char("Code", size=None, select=True, readonly=True)
     state = fields.Selection([
         ('draft', 'Draft'),
@@ -876,7 +925,9 @@ class ShipmentOut(Workflow, ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
         cursor = Transaction().cursor
+        sql_table = cls.__table__()
         # Migration from 1.2: packing renamed into shipment
         old_table = 'stock_packing_out'
         if TableHandler.table_exist(cursor, old_table):
@@ -898,22 +949,23 @@ class ShipmentOut(Workflow, ModelSQL, ModelView):
         Move = Pool().get('stock.move')
         if (not created_company
                 and TableHandler.table_exist(cursor, Move._table)):
-            cursor.execute('SELECT shipment.id, MAX(move.company) '
-                'FROM "%s" AS shipment '
-                'INNER JOIN "%s" AS move '
-                'ON \'%s,\' || shipment.id = move.shipment '
-                'GROUP BY shipment.id '
-                'ORDER BY MAX(move.company)'
-                % (cls._table, Move._table, cls.__name__))
+            move = Move.__table__()
+            cursor.execute(*sql_table.join(move,
+                    condition=(Concat(cls.__name__ + ',', sql_table.id)
+                        == move.shipment)
+                    ).select(sql_table.id, Max(move.company),
+                    group_by=sql_table.id,
+                    order_by=Max(move.company)))
             for company_id, values in itertools.groupby(cursor.fetchall(),
                     operator.itemgetter(1)):
                 shipment_ids = [x[0] for x in values]
                 for i in range(0, len(shipment_ids), cursor.IN_MAX):
                     sub_ids = shipment_ids[i:i + cursor.IN_MAX]
-                    red_sql, red_ids = reduce_ids('id', sub_ids)
-                    cursor.execute('UPDATE "' + cls._table + '" '
-                        'SET company = %s WHERE ' + red_sql,
-                        [company_id] + red_ids)
+                    red_sql = reduce_ids(sql_table.id, sub_ids)
+                    cursor.execute(*sql_table.update(
+                            columns=[sql_table.company],
+                            values=[company_id],
+                            where=red_sql))
             table.not_null_action('company', action='add')
 
         # Migration from 1.0 customer_location is no more used
@@ -939,10 +991,10 @@ class ShipmentOut(Workflow, ModelSQL, ModelView):
         return Transaction().context.get('company')
 
     def on_change_customer(self):
-        if not self.customer:
-            return {'delivery_address': None}
-        address = self.customer.address_get(type='delivery')
-        return {'delivery_address': address.id}
+        address = None
+        if self.customer:
+            address = self.customer.address_get(type='delivery')
+        return {'delivery_address': address.id if address else None}
 
     def on_change_with_customer_location(self, name=None):
         if self.customer:
@@ -998,6 +1050,15 @@ class ShipmentOut(Workflow, ModelSQL, ModelView):
                 'moves': value,
                 })
 
+    @classmethod
+    def get_origins(cls, shipments, name):
+        origins = {}
+        with Transaction().set_user(0, set_context=True):
+            for shipment in cls.browse(shipments):
+                origins[shipment.id] = ', '.join(set(itertools.ifilter(None,
+                            (m.origin_name for m in shipment.moves))))
+        return origins
+
     @classmethod
     @ModelView.button
     @Workflow.transition('draft')
@@ -1262,7 +1323,7 @@ class ShipmentOutReturn(Workflow, ModelSQL, ModelView):
             },
         domain=[
             ('id', If(In('company', Eval('context', {})), '=', '!='),
-                Get(Eval('context', {}), 'company', 0)),
+                Eval('context', {}).get('company', -1)),
             ],
         depends=['state'])
     customer = fields.Many2One('party.party', 'Customer', required=True,
@@ -1296,7 +1357,7 @@ class ShipmentOutReturn(Workflow, ModelSQL, ModelView):
     warehouse_input = fields.Function(fields.Many2One('stock.location',
             'Warehouse Input', on_change_with=['warehouse']),
         'on_change_with_warehouse_input')
-    incoming_moves = fields.Function(fields.One2Many('stock.move', None,
+    incoming_moves = fields.Function(fields.One2Many('stock.move', 'shipment',
             'Incoming Moves',
             domain=[
                 ('from_location', '=', Eval('customer_location')),
@@ -1310,7 +1371,7 @@ class ShipmentOutReturn(Workflow, ModelSQL, ModelView):
             depends=['state', 'warehouse', 'customer', 'customer_location',
                 'warehouse_input', 'company']),
         'get_incoming_moves', setter='set_incoming_moves')
-    inventory_moves = fields.Function(fields.One2Many('stock.move', None,
+    inventory_moves = fields.Function(fields.One2Many('stock.move', 'shipment',
             'Inventory Moves',
             domain=[
                 ('from_location', '=', Eval('warehouse_input')),
@@ -1327,6 +1388,7 @@ class ShipmentOutReturn(Workflow, ModelSQL, ModelView):
     moves = fields.One2Many('stock.move', 'shipment', 'Moves',
         domain=[('company', '=', Eval('company'))], depends=['company'],
         readonly=True)
+    origins = fields.Function(fields.Char('Origins'), 'get_origins')
     code = fields.Char("Code", size=None, select=True, readonly=True)
     state = fields.Selection([
         ('draft', 'Draft'),
@@ -1368,7 +1430,9 @@ class ShipmentOutReturn(Workflow, ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
         cursor = Transaction().cursor
+        sql_table = cls.__table__()
         # Migration from 1.2: packing renamed into shipment
         old_table = 'stock_packing_out_return'
         if TableHandler.table_exist(cursor, old_table):
@@ -1390,22 +1454,23 @@ class ShipmentOutReturn(Workflow, ModelSQL, ModelView):
         Move = Pool().get('stock.move')
         if (not created_company
                 and TableHandler.table_exist(cursor, Move._table)):
-            cursor.execute('SELECT shipment.id, MAX(move.company) '
-                'FROM "%s" AS shipment '
-                'INNER JOIN "%s" AS move '
-                'ON \'%s,\' || shipment.id = move.shipment '
-                'GROUP BY shipment.id '
-                'ORDER BY MAX(move.company)'
-                % (cls._table, Move._table, cls.__name__))
+            move = Move.__table__()
+            cursor.execute(*sql_table.join(move,
+                    condition=(Concat(cls.__name__ + ',', sql_table.id)
+                        == move.shipment)
+                    ).select(sql_table.id, Max(move.company),
+                    group_by=sql_table.id,
+                    order_by=Max(move.company)))
             for company_id, values in itertools.groupby(cursor.fetchall(),
                     operator.itemgetter(1)):
                 shipment_ids = [x[0] for x in values]
                 for i in range(0, len(shipment_ids), cursor.IN_MAX):
                     sub_ids = shipment_ids[i:i + cursor.IN_MAX]
-                    red_sql, red_ids = reduce_ids('id', sub_ids)
-                    cursor.execute('UPDATE "' + cls._table + '" '
-                        'SET company = %s WHERE ' + red_sql,
-                        [company_id] + red_ids)
+                    red_sql = reduce_ids(sql_table.id, sub_ids)
+                    cursor.execute(*sql_table.update(
+                            columns=[sql_table.company],
+                            values=[company_id],
+                            where=red_sql))
             table.not_null_action('company', action='add')
 
         # Add index on create_date
@@ -1428,11 +1493,11 @@ class ShipmentOutReturn(Workflow, ModelSQL, ModelView):
         return Transaction().context.get('company')
 
     def on_change_customer(self):
-        if not self.customer:
-            return {'delivery_address': None}
-        address = self.customer.address_get(type='delivery')
+        address = None
+        if self.customer:
+            address = self.customer.address_get(type='delivery')
         return {
-            'delivery_address': address.id,
+            'delivery_address': address.id if address else None,
             }
 
     def on_change_with_customer_location(self, name=None):
@@ -1515,6 +1580,15 @@ class ShipmentOutReturn(Workflow, ModelSQL, ModelView):
                     'planned_date': inventory_date,
                     })
 
+    @classmethod
+    def get_origins(cls, shipments, name):
+        origins = {}
+        with Transaction().set_user(0, set_context=True):
+            for shipment in cls.browse(shipments):
+                origins[shipment.id] = ', '.join(set(itertools.ifilter(None,
+                            (m.origin_name for m in shipment.moves))))
+        return origins
+
     @classmethod
     def create(cls, vlist):
         pool = Pool()
@@ -1689,7 +1763,7 @@ class ShipmentInternal(Workflow, ModelSQL, ModelView):
             },
         domain=[
             ('id', If(In('company', Eval('context', {})), '=', '!='),
-                Get(Eval('context', {}), 'company', 0)),
+                Eval('context', {}).get('company', -1)),
             ],
         depends=['state'])
     code = fields.Char("Code", size=None, select=True, readonly=True)
@@ -1703,14 +1777,14 @@ class ShipmentInternal(Workflow, ModelSQL, ModelView):
                 Bool(Eval('moves'))),
             },
         domain=[
-            ('type', 'in', ['storage']),
+            ('type', 'in', ['storage', 'lost_found']),
             ], depends=['state', 'moves'])
     to_location = fields.Many2One('stock.location', "To Location",
         required=True, states={
             'readonly': Or(Not(Equal(Eval('state'), 'draft')),
                 Bool(Eval('moves'))),
             }, domain=[
-            ('type', 'in', ['storage']),
+            ('type', 'in', ['storage', 'lost_found']),
             ], depends=['state', 'moves'])
     moves = fields.One2Many('stock.move', 'shipment', 'Moves',
         states={
@@ -1785,7 +1859,9 @@ class ShipmentInternal(Workflow, ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
         cursor = Transaction().cursor
+        sql_table = cls.__table__()
         # Migration from 1.2: packing renamed into shipment
         old_table = 'stock_packing_internal'
         if TableHandler.table_exist(cursor, old_table):
@@ -1806,22 +1882,23 @@ class ShipmentInternal(Workflow, ModelSQL, ModelView):
         Move = Pool().get('stock.move')
         if (not created_company
                 and TableHandler.table_exist(cursor, Move._table)):
-            cursor.execute('SELECT shipment.id, MAX(move.company) '
-                'FROM "%s" AS shipment '
-                'INNER JOIN "%s" AS move '
-                'ON \'%s,\' || shipment.id = move.shipment '
-                'GROUP BY shipment.id '
-                'ORDER BY MAX(move.company)'
-                % (cls._table, Move._table, cls.__name__))
+            move = Move.__table__()
+            cursor.execute(*sql_table.join(move,
+                    condition=(Concat(cls.__name__ + ',', sql_table.id)
+                        == move.shipment)
+                    ).select(sql_table.id, Max(move.company),
+                    group_by=sql_table.id,
+                    order_by=Max(move.company)))
             for company_id, values in itertools.groupby(cursor.fetchall(),
                     operator.itemgetter(1)):
                 shipment_ids = [x[0] for x in values]
                 for i in range(0, len(shipment_ids), cursor.IN_MAX):
                     sub_ids = shipment_ids[i:i + cursor.IN_MAX]
-                    red_sql, red_ids = reduce_ids('id', sub_ids)
-                    cursor.execute('UPDATE "' + cls._table + '" '
-                        'SET company = %s WHERE ' + red_sql,
-                        [company_id] + red_ids)
+                    red_sql = reduce_ids(sql_table.id, sub_ids)
+                    cursor.execute(*sql_table.update(
+                            columns=[sql_table.company],
+                            values=[company_id],
+                            where=red_sql))
             table.not_null_action('company', action='add')
 
         # Add index on create_date
@@ -2140,8 +2217,8 @@ class PickingList(CompanyReport):
                 from_location_ids.add(move.from_location.id)
                 to_location_ids.add(move.to_location.id)
 
-        from_locations = Location.search(list(from_location_ids))
-        to_locations = Location.search(list(to_location_ids))
+        from_locations = Location.browse(list(from_location_ids))
+        to_locations = Location.browse(list(to_location_ids))
 
         return {
             'from_location_ids': [l.id for l in from_locations],
@@ -2187,8 +2264,8 @@ class SupplierRestockingList(CompanyReport):
                 from_location_ids.add(move.from_location.id)
                 to_location_ids.add(move.to_location.id)
 
-        from_locations = Location.search(list(from_location_ids))
-        to_locations = Location.search(list(to_location_ids))
+        from_locations = Location.browse(list(from_location_ids))
+        to_locations = Location.browse(list(to_location_ids))
 
         return {
             'from_location_ids': [l.id for l in from_locations],
@@ -2234,8 +2311,8 @@ class CustomerReturnRestockingList(CompanyReport):
                 from_location_ids.add(move.from_location.id)
                 to_location_ids.add(move.to_location.id)
 
-        from_locations = Location.search(list(from_location_ids))
-        to_locations = Location.search(list(to_location_ids))
+        from_locations = Location.browse(list(from_location_ids))
+        to_locations = Location.browse(list(to_location_ids))
 
         return {
             'from_location_ids': [l.id for l in from_locations],
@@ -2281,8 +2358,8 @@ class InteralShipmentReport(CompanyReport):
                 from_location_ids.add(move.from_location.id)
                 to_location_ids.add(move.to_location.id)
 
-        from_locations = Location.search(list(from_location_ids))
-        to_locations = Location.search(list(to_location_ids))
+        from_locations = Location.browse(list(from_location_ids))
+        to_locations = Location.browse(list(to_location_ids))
 
         return {
             'from_location_ids': [l.id for l in from_locations],
